致命ID (豆瓣)
Description: 致命ID电影简介和剧情介绍,致命ID影评、图片、预告片、影讯、论坛、在线购票
Keywords: 致命ID,Identity,致命ID影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.93豆瓣电影Top250

# 致命ID Identity (2003)

导演: 詹姆斯·曼高德
编剧: 迈克尔·库尼
主演: 约翰·库萨克 / 雷·利奥塔 / 阿曼达·皮特 / 约翰·浩克斯 / 阿尔弗雷德·莫里纳 / 克里·杜瓦尔 / 约翰·C·麦金雷 / 威廉姆·李·斯科特 / 杰克·布塞 / 普路特·泰勒·文斯 / 瑞贝卡·德·莫妮 / 卡门·阿尔根齐亚诺 / 马绍尔·贝尔 / 莱拉·肯泽尔 / 马特·莱斯切尔 / 布莱特·罗尔 / 霍尔姆斯·奥斯本 / 弗雷德里克·科芬 / 乔·哈特 / 迈克尔·赫希 / 泰伦斯·伯尼·海恩斯
类型: 剧情 / 悬疑 / 惊悚
制片国家/地区: 美国
语言: 英语
上映日期: 2003-04-25(美国)
片长: 90分钟
又名: 杀人游戏 / 致命身份
IMDb: tt0309698
豆瓣评分
引用
8.8
776268人评价
5星
52.0%
4星
39.2%
3星
8.0%
2星
0.5%
1星
0.2%
好于 98% 悬疑片
好于 98% 惊悚片
想看 看过
评价:
推荐

## 致命ID的剧情简介 · · · · · ·

一个典型而又引人入胜的悬疑故事：一个汽车旅馆里，住进了10个人，他们中间有司机、妓女、过气女星、夫妇、警探和他的犯人，还有神秘的旅馆经理。这天风雨大作，通讯中断，10人被困在了旅馆里，惊悚的故事开始了。
他们一个接一个的死去，并且按照顺序留下牌号。10个人存活下来的渐渐变少，他们开始恐慌，互相猜忌，却无意间发现了彼此间的联系。但是，大家怀疑的嫌疑人却纷纷死去，谜团笼罩在旅馆狭小的空间里，这样的凶杀案件却有着人们猜不到的真相…… ©豆瓣

## 致命ID的演职员 · · · · · · ( 全部 47 )

- 詹姆斯·曼高德 导演
- 约翰·库萨克 演员
- 雷·利奥塔 演员
- 阿曼达·皮特 演员
- 约翰·浩克斯 演员
- 阿尔弗雷德·莫里纳 演员

## 致命ID的视频和图片 · · · · · · ( 视频评论1 · 添加 | 图片548 · 添加 )

## 喜欢这部电影的人也喜欢 · · · · · ·

  恐怖游轮

  禁闭岛

  记忆碎片

  七宗罪

  沉默的羔羊

  万能钥匙

  第六感

  看不见的客人

  蝴蝶效应

  致命魔术

我要写短评

## 致命ID的短评 · · · · · · ( 全部 151859 条 )

热门 / 最新 / 好友

### 1338 有用 綦 看过 2009-12-22 21:09:41

他的人格实在是个竞争市场。由此可见，寡头和垄断未尝不好。

### 2311 有用 同志亦凡人中文站 看过 2014-10-20 17:17:46

吓得我都要人格分裂了！！！以后打死都不要再看恐怖烧脑片！！！！！

### 7500 有用 谋杀游戏机 看过 2010-01-28 17:58:03

医生的治疗方案是让不同人格互相残杀以产生幸存者，但残杀所诞生的幸存者就不可能是最优人格

### 1820 有用 杨迪 看过 2015-05-29 20:43:05

哇！我是那个被剧透了也觉得好看的人，我好厉害！

### 847 有用 Η² 看过 2008-07-12 03:54:50

本以为是娱乐片，却是一部精彩的悬疑片，和《记忆碎片》一样，不到结尾不见真相。前段或许有些老套，但进行到中段的解谜阶段就很紧张了，后面的真相揭开后，又将剧情推向一个让人瞠目结舌的高潮，难得的是在结尾，居然再次给了观众心灵一记刺痛。善与恶，原本就是一体的。 PS:1.以罪犯幻想之情节名义给剧本许多地方逻辑推理不足找到了借口2.Mhotel又有何寓意呢3.对影片营造的黑夜，阴冷，潮湿氛围很中意last.... 本以为是娱乐片，却是一部精彩的悬疑片，和《记忆碎片》一样，不到结尾不见真相。前段或许有些老套，但进行到中段的解谜阶段就很紧张了，后面的真相揭开后，又将剧情推向一个让人瞠目结舌的高潮，难得的是在结尾，居然再次给了观众心灵一记刺痛。善与恶，原本就是一体的。 PS:1.以罪犯幻想之情节名义给剧本许多地方逻辑推理不足找到了借口2.Mhotel又有何寓意呢3.对影片营造的黑夜，阴冷，潮湿氛围很中意last.每个人或许都有多重人格，后怕。 H2 2008.7.12 03:38 (展开)

> 更多短评 151859条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 致命ID的影评 · · · · · · ( 全部 1175 条 )

热门 / 最新 / 好友
jmmjmm 2008-04-21 12:00:29

## 分析一下胖子的人格世界

这篇影评可能有剧透

分析一下胖子的人格世界，大家可以探讨一下。没看过片子的人就不要看下面的内容了，不然剧透了。 ***********************************************************防剧透分隔线************************************************* 列一下出场人物：过气的女明星和她的司机，三口... (展开)
18257 526 1371回应 收起
云航枫男 2008-04-29 00:45:30

## 请注意，主角有11重人格！～心理医生犯了一个致命的失误！～

这篇影评可能有剧透

先谈谈很多人所说的所谓的押运2个囚犯的警察和在冻柜里的死人，他们并不属于11重人格之一，因为很明显的，他们没有领到进入旅馆的生死牌。 很多人可能很在意主角的人格分析，而我却对一开始的心理医生在听录音记录十分感兴趣，心理医生明显的犯了一个致命的失误，他在... (展开)
1073 90 120回应 收起
L 2013-01-05 15:03:39

## 致命ID完全解析

这篇影评可能有剧透

麦肯芮佛的母亲是一个妓女，在他小时候常常虐待他，并且她在工作的时候就会把麦肯遗留在汽车旅馆里。如此的环境导致麦肯的内心遭受重大打击，产生了多重人格分裂症，分裂出了11个人格，分别是： 1.提姆西：一个看起来有点自闭的小男孩，很少说话，也不喜欢玩闹，很受父母的疼爱... (展开)
1456 34 114回应 收起
花橘子叔叔 2009-05-07 02:52:51

## 胖子都有颗敏感的心

印度教说，我们的世界不过是天神梵天的一个梦，每隔4万年，梵天会醒一次，他一醒，这个世界就幻灭了，直到梵天再次入睡，新的世界才从新开始 这部片子你可能会不喜欢，即使我推荐它，你也可能对这部片子很失望 你可能会骂它情节单薄禁不起推敲 ，故设悬念而无法自圆其说，结尾... (展开)
664 76 148回应 收起
451½°F™ 2008-05-31 13:36:05

## Identity

从那个多重人格分裂症患者Malcolm Rivers的主治医师的嘴里可以得知：影片中所呈现的旅馆杀人事件是医生对Malcolm Rivers使用强力药物治疗之后产生的效果。也就是说，医生为了治愈Malcolm Rivers的人格分裂，对他进行特殊的药物治疗，而这种药物所产生的直接后果就是使得Malcolm... (展开)
418 95 88回应 收起
豆瓣酱 2012-01-12 12:25:48

## 客观的时间轴整理（医生说的是死了10个人格，共11个人格！）

这篇影评可能有剧透

在我看过的推理侦探小说、电影、动漫作品中，这个电影算精神分裂影片中出色的一部。 虽然我喜欢诺兰，但我甚至觉得《致命ID》比《记忆碎片》更有逻辑，更好看一些。毕竟《记忆碎片》主角的病不是精神分裂。哎扯远了。 我反复观影至少3遍，也阅读了大量前人的评论，做出了总结如... (展开)
328 27 30回应 收起
卡卡同学『弗洛Y德』 2009-10-04 08:22:17

## ID可以和谐，如果真的知道SIN是谁的话

这篇影评可能有剧透

我一度认为在解离性人格实验小电影上它的存在可以算是一个经典，它的经典就在于那些不经意的片段中也深具挖掘的价值啊，有些细节，重看之后心里老觉得有趣，那就挖出来扯一下吧。 【D1】那首贯穿主题的小诗的意义 As I was going up the stairs 当我上楼时 　　I met a ... (展开)
215 22 28回应 收起
yangjinjlu 2010-04-02 22:51:10

## 医生好心办了坏事

这篇影评可能有剧透

我就说一句，细节无可挑剔的电影，牛！ 我对这部电影的总结就是一句话：医生好心办了坏事，结果造成一个人可以而且是肯定要去杀更多的人。 不止一位朋友对于女明星住的房间提出质疑，说女明星是住8号房，但是从9号房门出来，我刚开始也认为是电影的一个硬伤，但我后来弄明白... (展开)
179 13 10回应 收起
AirGiver 2006-05-06 03:26:43

## 很不错的悬疑片，带点轻微的恐怖色彩

这是一部非常对我胃口的电影，也就是所谓的悬疑片，带点恐怖色彩。 还是来谈谈电影，当然是2003年的老片子，可能大家很多人都看过了。故事发生在一个雨夜，开场是一个心理医生对一个连环杀人的变态杀人狂的采访记录，医生在经过分析后认为这是一个典型的人格分裂个案，而不应... (展开)
176 63 50回应 收起

> 更多影评 1175篇

添加新讨论

## 讨论区 · · · · · ·

司机打死假警察时为什么会说“I know” | 来自青意留 | 2 回应 | 2022-11-23 16:34:01
两个疑问or不合理 | 来自宫水三叶 | 5 回应 | 2022-11-23 16:30:02
我想问一下我在网上看到的同名致命ID的电影是个啥 | 来自许墨菲 | 6 回应 | 2022-11-14 19:55:40
！ | 来自有心人 |  | 2022-11-14 14:43:58
说句实话就是抖音火的。。当然豆瓣有些小心思，不... | 来自魔前一叩三千年 | 29 回应 | 2022-11-14 00:27:29

> 去这部影片的讨论区（全部342条）

## 关于《致命ID》的问题 · · · · · · ( 全部45个 )

- 门牌号的问题。？ 8人回答
- 完全不懂。。所有的杀人都是他人格臆想出来，不是真的吗？尸体是怎么被处理的啊？ 16人回答

> 全部45个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【意外结局】 (影志)
- 心理学电影(一句话剧透,不喜勿入) (何学卿)
- 简直想打十星 (chrissy)
- 他们是高智商玩家 (中间元素)

## 谁在看这部电影 · · · · · ·

- 嘎爵爷
  3分钟前 看过
- 沉默是最好的
  5分钟前 看过
- 小屁孩儿
  6分钟前 看过

1072458人看过 / 281340人想看

订阅致命ID的评论:
feed: rss 2.0